==> cego-2.52.34.tar.gz: cego-2.52.34/src/CegoProcObject.cc <==
///////////////////////////////////////////////////////////////////////////////
//                                                         
// CegoProcObject.cc 
// -----------------
// Cego procedure object implementation
//     
// Design and Implementation by Bjoern Lemke               
//     
// (C)opyright 2000-2025 Bjoern Lemke
//
// IMPLEMENTATION MODULE
//
// Class: CegoProcObject
//
// Description: Container class for Cego stored procedures
//
// Status: CLEAN
//
///////////////////////////////////////////////////////////////////////////////

// base includes
#include <lfcbase/Tokenizer.h>

// cego includes
#include "CegoProcObject.h"
#include "CegoXMLdef.h"

#include <string.h>
#include <stdlib.h>

CegoProcObject::CegoProcObject()
{
}

CegoProcObject::CegoProcObject(const CegoProcObject& po)  : CegoDecodableObject(po)
{
    _procText = po._procText;
}

CegoProcObject::CegoProcObject(const Chain& procName, int tabSetId) : CegoDecodableObject(CegoObject::PROCEDURE, procName, tabSetId)
{
}

CegoProcObject::CegoProcObject(int tabSetId, const Chain& procName, const Chain& procText) : CegoDecodableObject(CegoObject::PROCEDURE, procName, tabSetId)
{
    _procText = procText;
}

CegoProcObject::~CegoProcObject()
{   
}

int CegoProcObject::getEntrySize() const
{
    int entrySize = CegoObject::getBaseSize();
    entrySize += _procText.length() + 1;
    return entrySize;
}

void CegoProcObject::encode(char *buf) const
{
    char* bufPtr = buf;
    int entrySize = getEntrySize();
    CegoObject::encodeBase(bufPtr, entrySize);
    bufPtr += CegoObject::getBaseSize();
    memcpy (bufPtr, (char*)_procText , _procText.length() + 1);
}

void CegoProcObject::decode(char *buf)
{
    char* bufPtr = buf;
    int size;
    CegoObject::decodeBase(bufPtr, size);
    bufPtr += CegoObject::getBaseSize();
    _procText = Chain(bufPtr);
}

CegoProcObject& CegoProcObject::operator = ( const CegoProcObject& po)
{
    CegoObject::operator=(po);

    _procText = po._procText;
    return (*this);
}

bool CegoProcObject::operator == ( const CegoProcObject& po)
{
    return CegoObject::operator==(po);
}

const Chain& CegoProcObject::getProcText() const
{
    return _procText;
}

Chain CegoProcObject::toChain() const
{
    Chain s;
    
    s = CegoObject::toChain();
    s += Chain("Proc Text: ") + _procText + Chain("\n");
    s += Chain("EntrySize = ") + Chain(getEntrySize()) + Chain("\n");
    return s;
}

Chain CegoProcObject::getFormatted() const
{
    Chain s;
    int maxFillLen = 80;

    Chain line;

    Tokenizer ppt(_procText, "\n");	
    while ( ppt.nextToken(line) )
    {
	if ( line.length() > maxFillLen )
	    maxFillLen = line.length();
    }
    
    s += "+" + fill("-", maxFillLen) + "+\n";
    s += "| ObjectName : "+ getName() + fill(" ", maxFillLen - getName().length()-13) + "|\n";
    s += "| ObjectType : procedure" + fill(" ", maxFillLen-23) + "|\n";
    s += "+-----------------------" + fill("-", maxFillLen-23) +  "+\n";
    s += "| Procedure Text        " +  fill(" ", maxFillLen-23) + "|\n";
    s += "+" + fill("-", maxFillLen) + "+\n";
	
    Tokenizer pt(_procText, "\n");
    
    while ( pt.nextToken(line) )
    {
	s += "| " + line + fill(" ", maxFillLen-line.length()) + "|\n";
    }
    s +="+" + fill("-", maxFillLen) + "+\n";

    return s;
}

Chain CegoProcObject::fill(const Chain& s, int num) const
{
    Chain fs = Chain();
    while (num > 0)
    {
	fs = fs + s;
	num--;
    }
    return fs;
}

==> cego-2.52.44.tar.gz: cego-2.52.44/src/CegoProcObject.cc <==
///////////////////////////////////////////////////////////////////////////////
//                                                         
// CegoProcObject.cc 
// -----------------
// Cego procedure object implementation
//     
// Design and Implementation by Bjoern Lemke               
//     
// (C)opyright 2000-2025 Bjoern Lemke
//
// IMPLEMENTATION MODULE
//
// Class: CegoProcObject
//
// Description: Container class for Cego stored procedures
//
// Status: CLEAN
//
///////////////////////////////////////////////////////////////////////////////

// base includes
#include <lfcbase/Tokenizer.h>

// cego includes
#include "CegoProcObject.h"
#include "CegoXMLdef.h"

#include <string.h>
#include <stdlib.h>

CegoProcObject::CegoProcObject()
{
}

CegoProcObject::CegoProcObject(const CegoProcObject& po)  : CegoDecodableObject(po)
{
    _procText = po._procText;
}

CegoProcObject::CegoProcObject(const Chain& procName, int tabSetId) : CegoDecodableObject(CegoObject::PROCEDURE, procName, tabSetId)
{
}

CegoProcObject::CegoProcObject(int tabSetId, const Chain& procName, const Chain& procText) : CegoDecodableObject(CegoObject::PROCEDURE, procName, tabSetId)
{
    _procText = procText;
}

CegoProcObject::~CegoProcObject()
{   
}

int CegoProcObject::getEntrySize() const
{
    int entrySize = CegoObject::getBaseSize();
    entrySize += _procText.length() + 1;
    return entrySize;
}

void CegoProcObject::encode(char *buf) const
{
    char* bufPtr = buf;
    int entrySize = getEntrySize();
    CegoObject::encodeBase(bufPtr, entrySize);
    bufPtr += CegoObject::getBaseSize();
    memcpy (bufPtr, (char*)_procText , _procText.length() + 1);
}

void CegoProcObject::decode(char *buf)
{
    char* bufPtr = buf;
    int size;
    CegoObject::decodeBase(bufPtr, size);
    bufPtr += CegoObject::getBaseSize();
    _procText = Chain(bufPtr);
}

CegoProcObject& CegoProcObject::operator = ( const CegoProcObject& po)
{
    CegoObject::operator=(po);

    _procText = po._procText;
    return (*this);
}

bool CegoProcObject::operator == ( const CegoProcObject& po)
{
    return CegoObject::operator==(po);
}

const Chain& CegoProcObject::getProcText() const
{
    return _procText;
}

Chain CegoProcObject::getInfo() const
{
    Chain s;   
    s = Chain("Proc Text: ") + _procText + Chain("\n");
    return s;
}
